SMDiscard class

SMRouter.handle("/discard", (ctx) => const Text("不会跳转到路由 /discard")).use((ctx) => SMDiscard());

Inheritance

Constructors

SMDiscard()
取消路由跳转
const

Properties

arguments Object?
The arguments passed to this route.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the route (e.g., "/settings").
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited