SMRoutePage<T> class

Inheritance
Implementers

Constructors

SMRoutePage({LocalKey? key, String? name, Object? arguments, String? restorationId, required Widget child, required RouteTransitionsBuilder transitionsBuilder, Duration transitionDuration = const Duration(milliseconds: 300), Duration reverseTransitionDuration = const Duration(milliseconds: 300), bool opaque = true, bool barrierDismissible = false, Color? barrierColor, String? barrierLabel, bool maintainState = true, bool fullscreenDialog = false})
const

Properties

arguments Object?
The arguments passed to this route.
finalinherited
barrierColor Color?
final
barrierDismissible bool
final
barrierLabel String?
final
canPop bool
When false, blocks the associated route from being popped.
finalinherited
child Widget
final
fullscreenDialog bool
final
hashCode int
The hash code for this object.
no setterinherited
key LocalKey?
The key associated with this page.
finalinherited
maintainState bool
final
name String?
The name of the route (e.g., "/settings").
finalinherited
onPopInvoked PopInvokedWithResultCallback<T>
Called after a pop on the associated route was handled.
finalinherited
opaque bool
final
restorationId String?
Restoration ID to save and restore the state of the Route configured by this page.
finalinherited
reverseTransitionDuration Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionDuration Duration
final
transitionsBuilder RouteTransitionsBuilder
final

Methods

canUpdate(Page other) bool
Whether this page can be updated with the other page.
inherited
createRoute(BuildContext context) Route<T>
Creates the Route that corresponds to this page.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited